##  Business Capability Recommendations for Applications While Adding Relations
While linking business capabilities to applications, you automatically get recommendations to help you choose the most relevant ones. It helps improve overall data quality by highlighting gaps and offering recommendations. To generate them, the system semantically compares the application's name and description with those of business capabilities in your workspace.
**Remember**
Business capability recommendations appear only after the application description has been completed.
![Business Capability Recommendations While Adding Relations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio428c190aa60e41c49dc1ec25f9327c6a_LowRes.png)
Business Capability Recommendations
You receive suggestions in the application fact sheets as well as during inline editing in the inventory's table view mode. To learn about inline editing, see [Inline Editing](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD#loioc61816d6a4da4c5fbc9bc6365f2646c2__inline_editing).
Additionally, you can find all recommendations in the Recommendations tab of the fact sheet, making it easy to review and manage them in one place. For more, see Filling Fact Sheet Data from Recommendations.
